@@ -4,9 +4,10 @@ Python version：3.9
 来源于:https://blog.csdn.net/yanxilou/article/details/119645290
 '''
 
-from yaoys.tools.log import logutil
 import time
 
+import yaoysTools.log.logutil as logutil
+
 # 64位ID的划分
 WORKER_ID_BITS = 5
 DATACENTER_ID_BITS = 5
@@ -25,10 +26,10 @@ SEQUENCE_MASK = -1 ^ (-1 << SEQUENCE_BITS)
 # Twitter元年时间戳
 TWEPOCH = 1288834974657
 
-logger = logutil.mylog(logger='[snowflake]').get_logger()
+logger = logutil.getLogger(log_name='[snowflake]', log_level=logutil.MY_LOG_INFO)
 
 
-class IdWorker(object):
+class snowFlakeId(object):
     """
     用于生成IDs
     """
@@ -95,10 +96,10 @@ class IdWorker(object):
 
 
 def get_id():
-    worker = IdWorker(1, 2, 0)
+    worker = snowFlakeId(1, 2, 0)
     for x in range(1, 10):
-        print(worker.get_id())
-        logger.info(worker.get_id())
+        # print(worker.get_id())
+        logutil.log_info(worker.get_id(), my_logger=logger)
 
 
 if __name__ == '__main__':
